@@ -10,12 +10,11 @@ from .dom import (
     BoundingBox,
     parse_html,
     parse_cdp,
-    apply_visibility_filters,
-    apply_semantic_filters,
     DomSnapshot,
-    serialize_to_markdown,
 )
 
+from .llm_browser.dom_filter_config import DomFilterConfig
+
 from .llm import (
     Context,
     Block,
@@ -23,6 +22,8 @@ from .llm import (
     LLM,
 )
 
+from .media import Image
+
 __version__ = "0.1.0"
 
 __all__ = [
@@ -42,17 +43,18 @@ __all__ = [
     'parse_html',
     'parse_cdp',
 
-    # Filters
-    'apply_visibility_filters',
-    'apply_semantic_filters',
-
     # Snapshot
     'DomSnapshot',
-    'serialize_to_markdown',
+
+    # Config
+    'DomFilterConfig',
 
     # LLM
     'Context',
     'Block',
     'Tokenizer',
     'LLM',
+
+    # Media
+    'Image',
 ]
