@@ -8,11 +8,7 @@ from .parsers import parse_cdp
 
 @dataclass
 class DomSnapshot:
-    """
-    DOM snapshot with metadata.
-
-    Pure data structure capturing a snapshot of the DOM at a specific point in time.
-    """
+    """DOM snapshot with metadata."""
 
     root: DomNode
     url: Optional[str] = None
@@ -21,15 +17,6 @@ class DomSnapshot:
 
     @classmethod
     def from_cdp(cls, cdp_snapshot: Dict[str, Any], url: Optional[str] = None) -> 'DomSnapshot':
-        """
-        Create DomSnapshot from CDP (Chrome DevTools Protocol) snapshot.
-
-        Args:
-            cdp_snapshot: CDP DOMSnapshot.captureSnapshot response
-            url: Optional URL of the page
-
-        Returns:
-            DomSnapshot instance with parsed DOM tree
-        """
+        """Create DomSnapshot from CDP snapshot."""
         root = parse_cdp(cdp_snapshot)
         return cls(root=root, url=url)
